PlatformExceptionCode class
A class contains the error code from PlatformException
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- argumentError → const String
- The code indicates invalid arguments were passed to a native method
- canceled → const String
- The code indicates an operation was canceled
- conflict → const String
- The code indicates a version-exposure failure (conflict enumeration, copy-out, or mark-resolved). The auto-resolve producer that previously emitted this code has been removed; the plugin only exposes versions and never auto-resolves-and-deletes losing versions.
- coordination → const String
- The code indicates file coordination failed.
- fileNotFound → const String
- The code indicates file not found
- fileNotFoundRead → const String
- The code indicates file not found during a read operation
- fileNotFoundWrite → const String
- The code indicates file not found during a write operation
- iCloudConnectionOrPermission → const String
- The code indicates iCloud container ID is not valid, or user is not signed in to iCloud, or user denied iCloud permission for this app
- initializationError → const String
- The code indicates the plugin was not properly initialized on the native side.
- invalidEvent → const String
- The code indicates the native layer sent an invalid event type This represents a bug in the plugin. Please open a GitHub issue if you encounter this error.
- nativeCodeError → const String
- The code indicates other error from native code
- noEventHandler → const String
- The code indicates an event channel was not created before use.
- pluginInternal → const String
- The code indicates an internal plugin error occurred in Dart code This represents a bug in the plugin. Please open a GitHub issue if you encounter this error.
- readError → const String
- The code indicates a file read operation failed