conflict constant
String
const conflict
The code indicates the operation failed due to a coordination conflict.
Implementation
static const String conflict = 'E_CONFLICT';
The code indicates the operation failed due to a coordination conflict.
static const String conflict = 'E_CONFLICT';