itemNotDownloaded constant
String
const itemNotDownloaded
The code indicates the item is not downloaded locally yet.
Implementation
static const String itemNotDownloaded = 'E_NOT_DOWNLOADED';
The code indicates the item is not downloaded locally yet.
static const String itemNotDownloaded = 'E_NOT_DOWNLOADED';