ICloudDownloadInProgressException class
Thrown when a download is already active for the item.
- Inheritance
-
- Object
- ICloudOperationException
- ICloudDownloadInProgressException
Properties
- category → String
-
Stable error category from the native payload.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable failure message.
finalinherited
- nativeCode → int?
-
Native error code, when present.
finalinherited
- nativeDescription → String?
-
Native error description, when present.
finalinherited
- nativeDomain → String?
-
Native error domain, when present.
finalinherited
- operation → String
-
Operation name that failed.
finalinherited
- pathKind → String?
-
Non-PII classification of the native path involved in the failure.
finalinherited
- relativePath → String?
-
Relative path associated with the failure, when present.
finalinherited
- retryable → bool
-
Whether retrying the operation may succeed.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underlying → Object?
-
Underlying native error payload, when present.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited