ICloudOperationException class
Base class for typed iCloud operation failures surfaced from native code.
- Implemented types
- Implementers
Constructors
- ICloudOperationException({required String category, required String operation, required bool retryable, required String message, String? relativePath, String? pathKind, String? nativeDomain, int? nativeCode, String? nativeDescription, Object? underlying})
-
Creates a typed iCloud operation exception.
const
Properties
- category → String
-
Stable error category from the native payload.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable failure message.
final
- nativeCode → int?
-
Native error code, when present.
final
- nativeDescription → String?
-
Native error description, when present.
final
- nativeDomain → String?
-
Native error domain, when present.
final
- operation → String
-
Operation name that failed.
final
- pathKind → String?
-
Non-PII classification of the native path involved in the failure.
final
- relativePath → String?
-
Relative path associated with the failure, when present.
final
- retryable → bool
-
Whether retrying the operation may succeed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- underlying → Object?
-
Underlying native error payload, when present.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited