ICloudTransferProgress class

A typed data event emitted from upload/download progress streams.

Failures are delivered through the stream error channel as typed ICloudOperationException values.

Constructors

ICloudTransferProgress.done()
Creates a completion event.
const
ICloudTransferProgress.progress(double percent)
Creates a progress update event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDone bool
Whether this event represents successful completion.
no setter
isProgress bool
Whether this event represents a progress update.
no setter
percent double?
Upload/download progress as a percentage.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ICloudTransferProgressType
The kind of data event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited